==> jboss-eap-8.1.0-server-migration-src.zip: jboss-eap-8.1-server-migration-src/servers/wildfly34.0/src/main/java/org/jboss/migration/wfly/WildFly34_0ServerProvider.java <==
/*
 * Copyright 2024 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.migration.wfly;

import org.jboss.migration.core.ProductInfo;
import org.jboss.migration.core.Server;
import org.jboss.migration.core.env.MigrationEnvironment;

import java.nio.file.Path;

/**
 * The WildFly 34.x {@link org.jboss.migration.core.ServerProvider}.
 *  @author emmartins
 */
public class WildFly34_0ServerProvider extends WildFly33_0ServerProvider {

    @Override
    protected String getProductNameRegex() {
        return "WildFly";
    }

    @Override
    protected String getProductVersionRegex() {
        return "34\\..*";
    }

    @Override
    protected Server constructServer(String migrationName, ProductInfo productInfo, Path baseDir, MigrationEnvironment migrationEnvironment) {
        return new WildFly34_0Server(migrationName, productInfo, baseDir, migrationEnvironment);
    }

    @Override
    public String getName() {
        return "WildFly 34.x";
    }
}

==> jboss-eap-8.1.1-server-migration-src.zip: jboss-eap-8.1-server-migration-src/servers/wildfly28.0/src/main/java/org/jboss/migration/wfly/WildFly28_0ServerProvider.java <==
/*
 * Copyright 2021 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.migration.wfly;

import org.jboss.migration.core.ProductInfo;
import org.jboss.migration.core.Server;
import org.jboss.migration.core.env.MigrationEnvironment;
import org.jboss.migration.wfly10.dist.full.WildFlyFullServerProvider10_0;

import java.nio.file.Path;

/**
 * The WildFly 28.x {@link org.jboss.migration.core.ServerProvider}.
 *  @author emmartins
 */
public class WildFly28_0ServerProvider extends WildFlyFullServerProvider10_0 {

    @Override
    protected String getProductModuleId() {
        return "org.jboss.as.product";
    }

    @Override
    protected String getProductVersionRegex() {
        return "28\\..*";
    }

    @Override
    protected Server constructServer(String migrationName, ProductInfo productInfo, Path baseDir, MigrationEnvironment migrationEnvironment) {
        return new WildFly28_0Server(migrationName, productInfo, baseDir, migrationEnvironment);
    }

    @Override
    public String getName() {
        return "WildFly 28.x";
    }
}
